Documentation
¶
Index ¶
- func Debugf(format string, args ...any)
- func Debugw(msg string, keyvals ...any)
- func Errorf(format string, args ...any)
- func Errorw(err error, msg string, keyvals ...any)
- func Fatalf(format string, args ...any)
- func Fatalw(msg string, keyvals ...any)
- func Infof(format string, args ...any)
- func Infow(msg string, keyvals ...any)
- func Init(opts *Options, options ...Option)
- func NewLogger(opts *Options, options ...Option) *logger
- func Panicf(format string, args ...any)
- func Panicw(msg string, keyvals ...any)
- func SetLevel(level string)
- func Warnf(format string, args ...any)
- func Warnw(msg string, keyvals ...any)
- type Logger
- type Option
- type Options
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Logger ¶
type Logger interface {
Debugf(format string, args ...any)
Debugw(msg string, keyvals ...any)
Infof(format string, args ...any)
Infow(msg string, keyvals ...any)
Warnf(format string, args ...any)
Warnw(msg string, keyvals ...any)
Errorf(format string, args ...any)
Errorw(err error, msg string, keyvals ...any)
Panicf(format string, args ...any)
Panicw(msg string, keyvals ...any)
Fatalf(format string, args ...any)
Fatalw(msg string, keyvals ...any)
SetLevel(level string)
W(ctx context.Context) Logger
AddCallerSkip(skip int) Logger
Sync()
// integrate other loggers
gormlogger.Interface
}
Logger defines the interface of a logger.
func AddCallerSkip ¶
type Options ¶
type Options struct {
// DisableCaller specifies whether to include caller information in the log.
DisableCaller bool `json:"disable-caller,omitempty" mapstructure:"disable-caller"`
// DisableStacktrace specifies whether to record a stack trace for all messages at or above panic level.
DisableStacktrace bool `json:"disable-stacktrace,omitempty" mapstructure:"disable-stacktrace"`
// EnableColor specifies whether to output colored logs.
EnableColor bool `json:"enable-color" mapstructure:"enable-color"`
// Level specifies the minimum log level. Valid values are: debug, info, warn, error, dpanic, panic, and fatal.
Level string `json:"level,omitempty" mapstructure:"level"`
// Format specifies the log output format. Valid values are: console and json.
Format string `json:"format,omitempty" mapstructure:"format"`
// OutputPaths specifies the output paths for the logs.
OutputPaths []string `json:"output-paths,omitempty" mapstructure:"output-paths"`
// EnableFile specifies whether to enable file logging.
EnableFile bool `json:"enable-file,omitempty" mapstructure:"enable-file"`
// LogDir specifies the directory to store the logs.
LogDir string `json:"log-dir,omitempty" mapstructure:"log-dir"`
// MaxSize is the maximum size in megabytes of the log file before it gets rotated.
MaxSize int `json:"max-size,omitempty" mapstructure:"max-size"`
// MaxBackups is the maximum number of old log files to retain.
MaxBackups int `json:"max-backups,omitempty" mapstructure:"max-backups"`
// MaxAge is the maximum number of days to retain old log files based on the timestamp encoded in their filename.
MaxAge int `json:"max-age,omitempty" mapstructure:"max-age"`
// Compress determines if the rotated log files should be compressed using gzip.
Compress bool `json:"compress,omitempty" mapstructure:"compress"`
}
Options contains configuration options for logging.
func NewOptions ¶
func NewOptions() *Options
NewOptions creates a new Options object with default values.
Click to show internal directories.
Click to hide internal directories.